--[[
	##AddOn	: GuildXP
	##Subfile	: main.lua
	##Author  : Hati ( xhatix on wowace.com )
--]]
local ldb = LibStub("LibDataBroker-1.1")
if not ldb then print("GuildXP loading failed. LibDataBroker-1.1 missing.") return end
local strformat = string.format
aLDBGuildXP = CreateFrame("Frame","GuildXP_LDB")
local GX = aLDBGuildXP
GX:RegisterEvent("GUILD_XP_UPDATE")
GX:RegisterEvent("PLAYER_LOGIN")
GX.name = "GuildXP"
GX.version = function() 
	local r = GetAddOnMetadata( GX.name, 'Version')
	if r == "@project-version" then
		return "SVN-Develop"
	else
		return r
	end
end

GX.InitAddon = function()
    GX.initialized=true
    QueryGuildXP()
    GX.UpdateText = function()
        return --[["Level: "..GX:GetGuildLevel().." | ]]"GuildXP: "..GX:GetGuildXP()
    end
    GX.ldb = ldb:NewDataObject("GuildXP",{
        type='data source',
        label='GuildXP',
        text="",
        --tooltip=GX.tooltip,
        OnEnter=function(self)
            if IsInGuild() then
                --foreach(self,print)
                GX.tooltip:SetPoint("TOPLEFT",self,"TOPLEFT",0,-10)
                GX.tooltip.texture:SetAllPoints(GX.tooltip)
                GX.tooltip.text:SetPoint("TOPLEFT",GX.tooltip,"TOPLEFT",0,5)
                GX.updateTooltip()
                GX.tooltip:Show()
            end
        end,        
        OnLeave=function() GX.tooltip:Hide() end,
    })
end

GX.updateTooltip = function()
    local function AddLine(text,line)
        return text.."\n"..line
    end
    local cXP,remainingXP,dailyXP,dailyMaxXP = UnitGetGuildXP("player")
    local maxXP = cXP+remainingXP
    local pXP,usedDailyXPPerc = (cXP/maxXP), (dailyXP/dailyMaxXP)
    local t = ""
    t=AddLine(t,"Current Guild Level: "..GX:GetGuildLevel())
    t=AddLine(t,"Current Guild experience: "..cXP.." ( "..strformat("%.1f", pXP*100).."% )")
    t=AddLine(t,"Remaining Guild experience: "..remainingXP.."( "..strformat("%.1f", pXP).." )")
    t=AddLine(t,"Daily XP-Cap: "..dailyXP.." ( "..strformat("%.1f", usedDailyXPPerc*100).."% )")
    t=AddLine(t,"Unused Daily XP: "..dailyMaxXP-dailyXP.." ( "..strformat("%.1f", (1-usedDailyXPPerc)*100).."% )")
    t=AddLine(t,"Days till next Level: "..math.ceil(remainingXP/dailyMaxXP).." days.")
    GX.tooltip.text:SetText(t)
    GX.tooltip:SetSize(GX.tooltip.text:GetWidth(),GX.tooltip.text:GetHeight())
end

GX.initialized = false
GX.PLAYER_LOGIN = function(addon)
    --if addon==GX.name then
        if not GX.initialized then GX:InitAddon() end
        GX.ldb.text=GX:UpdateText()       
    --end
    QueryGuildXP()
end
GX.GUILD_XP_UPDATE = function(...)
    GX.ldb.text=GX:UpdateText()
    if GX.tooltip:IsShown() then
        GX:updateTooltip()
    end
end
GX:SetScript("OnEvent",function(self,event,...)
    if GX[event] then GX[event](...) end
end)

GX.GetGuildLevel = function()
    if IsInGuild() then return UnitGetGuildLevel("player") end
end
GX.GetGuildXP = function()
    if IsInGuild() then
        QueryGuildXP()
        local cXP,remaining,dailyXP,dailyMaxXP = UnitGetGuildXP("player")
        local mXP = cXP+remaining
        local usedUpDaily = max(0,dailyXP/dailyMaxXP)
        return strformat("%d / %d "..GX:GetSuffix().." ( %.1f%% )", cXP, mXP,(cXP/mXP)*100)
    else
        return "No Guild"
    end
end
GX.GetSuffix = function()
    if IsInGuild() then
        return " XP"
    end
end

--Tooltip
GX.tooltip = CreateFrame("Frame", "GuildXP_LDB_Tooltip")
GX.tooltip:SetSize(140,60)
GX.tooltip:SetPoint("CENTER")
GX.tooltip:SetFrameStrata("TOOLTIP")
GX.tooltip:Hide()
GX.tooltip.texture = GX.tooltip:CreateTexture(GX.tooltip:GetName().."_Texture","OVERLAY")
GX.tooltip.texture:SetTexture(0.05,0.1,0.15,1)
GX.tooltip.texture:SetAllPoints(GX.tooltip)
--GX.tooltip:SetPoint(
GX.tooltip.text = GX.tooltip:CreateFontString(GX.tooltip:GetName().."Text","OVERLAY")
GX.tooltip.text:SetFont("Fonts\\FRIZQT__.TTF",12,"OUTLINE")
GX.tooltip.text:SetTextColor(1,1,1,1)
GX.tooltip.text:SetText("")


